##  Summary
In this tutorial, we explored how to use facets in the LeanIX Reporting Framework to filter data when creating a custom report. You learned how to:
  * Use the attributes field within facets to extract the completion attribute from the completion object of fact sheets
  * Calculate the average completion score for each fact sheet type, which is important for data analysis
  * Use filters located in the filter sidebar within the Reports section of the SAP LeanIX user interface, which enables you to interact with the data available in the LeanIX Reporting Library, allowing for dynamic data manipulation


YesNo
Send
